Learn R Programming

lisp (version 0.2)

zip: Zip n lists together into tuplets of length n.

Description

Zip n lists together into tuplets of length n.

Usage

zip(zipper, ...)

Value

A list of tuplets

Arguments

zipper

the zipping function

...

the lists to be zipped